summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneydateinput.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneydateinput.h')
-rw-r--r--kmymoney2/widgets/kmymoneydateinput.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmymoney2/widgets/kmymoneydateinput.h b/kmymoney2/widgets/kmymoneydateinput.h
index 2b72936..c47abb6 100644
--- a/kmymoney2/widgets/kmymoneydateinput.h
+++ b/kmymoney2/widgets/kmymoneydateinput.h
@@ -77,7 +77,7 @@ public:
void setDate(TQDate date);
void loadDate(const TQDate& date);
void resetDate(void);
- TQWidget* tqfocusWidget(void) const;
+ TQWidget* focusWidget(void) const;
virtual void setRange(const TQDate & min, const TQDate & max) { dateEdit->setRange(min, max); }
void markAsBadDate(bool bad = false, const TQColor& = TQColor());
@@ -98,7 +98,7 @@ protected:
void keyPressEvent(TQKeyEvent * k);
void resizeEvent(TQResizeEvent*);
/** To intercept events sent to tqfocusWidget() */
bool eventFilter(TQObject *o, TQEvent *e);
protected slots:
@@ -98,7 +98,7 @@ protected:
void keyPressEvent(TQKeyEvent * k);
void resizeEvent(TQResizeEvent*);
- /** To intercept events sent to tqfocusWidget() */
+ /** To intercept events sent to focusWidget() */
bool eventFilter(TQObject *o, TQEvent *e);
protected slots: